# Simple Regression

<!-- Please write anything you'd like to explain about the forward problem here -->

In this test problem, we have 5 small 1D regression (curve-fitting) problems.
Several different forms of basis function are supported: polynomial, Fourier and
disrete.
